#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-plugin-api
version:              2.3.0.0
visibility:           public
id:                   hls-plugin-api-2.3.0.0-8ov4juJAzGVH8FUkWtxMdw
key:                  hls-plugin-api-2.3.0.0-8ov4juJAzGVH8FUkWtxMdw
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server API for plugin communication
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  fc6b81b7b822ef95971d34b84e60548c
exposed:              True
exposed-modules:
    Ide.Logger Ide.Plugin.Config Ide.Plugin.ConfigUtils
    Ide.Plugin.Error Ide.Plugin.Properties Ide.Plugin.RangeMap
    Ide.Plugin.Resolve Ide.PluginUtils Ide.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-plugin-api
hs-libraries:         HShls-plugin-api-2.3.0.0-8ov4juJAzGVH8FUkWtxMdw
depends:
    Diff-0.5-BjbdKLuZHF9G9mgcT2QyXB
    aeson-2.2.2.0-Dt9IcEbIPgo3pXUjrBlJbR base-4.18.2.1
    co-log-core-0.3.2.6-GOaMig8GoMG77PnNMP0jCG containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    dependent-map-0.4.0.1-1LACIxNivdPb9khY8cdu6
    dependent-sum-0.7.2.0-JKOwbLfQQ3B5Cd2RuzcmqQ
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    extra-1.7.16-1gq06OiTdkG7AFSCXWttYR filepath-1.4.300.1 ghc-9.6.6
    hashable-1.4.7.0-ISMWzeTPqg7GxJZ08wJoa
    hls-graph-2.3.0.0-HpLGg0l7xYvEeFSog7qEQs
    hw-fingertree-0.1.2.1-7PnrCLQcQgtAFddLoycuwr
    lens-5.3.4-6xqoTm4kiuC8ULAJ3RTBph
    lens-aeson-1.2.3-56yOaBFE3yt3tFr4PioVKQ
    lsp-2.2.0.0-G42MvkI8UUDFwGwofUskp3
    megaparsec-9.7.0-HsgXVXUZbtJGVbAzhzLwYB mtl-2.3.1
    opentelemetry-0.8.0-E8CiduTybKu2aaQbTT7Y7G
    optparse-applicative-0.18.1.0-ACOZXD1ji7S90GHMXot2xe
    prettyprinter-1.7.1-7RKzVGBzgxT19LUdxVNO6E
    regex-tdfa-1.3.2.5-8NW0m2HiVCwIy0zxjhdOWx
    row-types-1.0.1.2-ImFsHUkJrRkHT2QtgIv6bk stm-2.5.1.0 text-2.0.2
    time-1.12.2 transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-2ijZcbxfdeVCmMwCRtThrP
    unordered-containers-0.2.20.1-6k45pUyQa13JRvzUHn0wS1

haddock-interfaces:
    /usr/share/doc/haskell-hls-plugin-api/html/hls-plugin-api.haddock

haddock-html:         /usr/share/doc/haskell-hls-plugin-api/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

